# first, get your data out of Excel into a format that R can read.  use File-->Save As... then select comma separated list from the drop-down menu.  if you have a workbook w/ multiple sheets it will warn you to say that it's only saving the current sheet; that's fine, and if you want to save multiple sheets as .csv files you have to do them one-by-one.

setwd('/Users/dkleinschmidt/Dropbox/RegressionTutorial/')
dat = read.csv('davedata.csv')

# use head() to get look at the first few rows of this dataset:
head(dat)
# and names() to get a list of the variable names
names(dat)

# this dataset is in "wide" format, with repeated observations of the same dependent variables spread across different columns.

# the point is to get each dependent variable in its own column, with no duplication.  in this case, there are two dependent variables: proportion of looks to animal and object, and these are distributed across four variables each (one for each cell in the 2x2 design) 'a1XX' and 'o1XX' where X is either 'D' or 'P'.

# we can use the melt() command in the reshape package to get it into a "long" format, where ALL measured variables are put into a single column ('value'), and the variable name is put in a new column ('variable')
library(reshape)
dat.m <- melt(dat, id.vars=1:9)
head(dat.m)

# now things get a bit tricky: some of our ID variables are hidden in the variable names. these are: which dependent measure the variable corresponds to (looks to animal or object), the prime structure, and the target structure.  the reshape package provides the colsplit() function to help with this (although in situations where the variable naming scheme isn't so simple something more complicated will be necessary).
conditionVars <- colsplit(dat.m$variable, names=c('look', 'one', 'primeStruct', 'targetStruct'))
head(conditionVars)

# these new variables can be added back to the melted data using the cbind() function, which takes two data.frames (or matrices, more generally) and binds their colums together---hence the name
dat.m <- cbind(dat.m, conditionVars[c(1,3,4)])
head(dat.m)

# we use the cast() function to convert the melted data into a dataframe with columns for 'a' and 'o', and one row per item and condition combination.
head(dat.cast <- cast(dat.m, item+primeStruct+targetStruct ~ look))

# since the dependent measure is the difference between proportion looks to animal and looks to object, we need to add a new column to this:
dat.cast$diff <- dat.cast$a - dat.cast$o
head(dat.cast)

# NOW we can finally do some analysis: run an ANOVA, using the aov command.
# ENTER THE FORMULA
anova.fit = aov(diff ~ primeStruct*targetStruct, data=dat.cast)
# a strength of R: aov() returns an object, which preserves all the juicy innards (like the function call that produced it, the fitted values predicted by the ANOVA, etc.) but which allows standard functions like print(), summary(), and plot() to be extended for use w/ the output of the model:
summary(anova.fit)


# COOL, RIGHT? in just EIGHT lines of code we've gone from nasty Excel datafile to ANOVA p-values.
