# First things first: what is R?

# R is a calculator:
1+1
# ...a bunch of statistical tables
qnorm(.975)
# and many, many, many libraries written and maintained by users
library(languageR)

# Why use R?  All of the things we'll show you today can be done with pretty much ANY programming language.  R is good for data analysis because it is both a full-featured programming language and specialized for data analysis and statistics.  unfortunately, this means that it's confusing and frustrating to learn for competent programmers and competent data-analyzers alike.  but once you get some basic things and some experience under your belt, it's as efficient as dedicated stats software and as powerful as any other programming language.

# so: where to start?  assuming minimal programming background:

# you can type commands directly into the COMMAND LINE, but it's better to use the script editor (or your favorite text editor).

# if you type a command that returns a value, that value will be printed to the command line:
1+1
'hello, world!'

# you can assign values to variables (using either '=' or '<-', just for the sake of being confusing---I mean backwards-compatible with S...)
three = 1+2
four <- three+1
greeting = 'hello, world!'

# functions take values, do things to them, and possibly return new values:
log(10)
exp(log(10))

# to get help on a function, type ? before its name:
?exp

# you can write your own functions REALLY easily (this is one of the really, really nice things about R (versus, say, Matlab):
my.fcn <- function(x) {
  print('yeah, I\'m a function')
  return(x+1)
}

my.fcn(4)

# some R-ontology:
# EVERYTHING IS A VECTOR, like in Matlab (which explains the [1] before all the printed values before).
# use c() to construct new vectors
c(1, 2, 3)
# and to merge existing vectors:
x = c(1,2,3)
y = c(4,5,6)
c(x,y)

# there are other functions to create vectors, a few useful ones are:
seq(1,10,2)   # count from 1 up by 2s, stopping at or before 10
rep(4,6)      # a vector of six 4s

# to get a single element from a vector, use square brackets:
y
y[1]     # first item of y (1-indexed!)
y[2:3]   # items 2 through 3 of y
y[-2]    # every item of y but the second
y[c(1,3)]# items 1 and 3 of y

# you can assign values to a subset of a vector without changing the rest:
y[2] = 0
y


# data frames are a central R construct, and are the way that the built-in data analysis functions (and the vast majority of external libraries) expect your data to be represented.
# data frames are organized into rows of observations, with each column representing the value of a variable:

# create some fake data and put it in a data frame:
x = runif(100,0,1)
df = data.frame(x=x, y=x+rnorm(100,0,.1))

# look at the first few rows:
head(df)
# look at a scatterplot of the fake data:
plot(df$x, df$y)
# add a variable:
df$diff = df$y - df$x

# at their heart, data frames are matrices, or two-dimensional vectors.  thus the same kind of subscripting mechanics can be used
df[55, 2]    # row 55, column 2
df[10:20, ]  # rows 10 through 20, all columns.
# note the comma above. if you want everything on one dimension, just leave that field empty.
head(df[,2]) # equivalent to head(df$y)
